summaryrefslogtreecommitdiff
path: root/dns/opcode.py
diff options
context:
space:
mode:
authorBob Halley <halley@dnspython.org>2020-05-08 07:02:48 -0700
committerBob Halley <halley@dnspython.org>2020-05-08 07:02:48 -0700
commitc8484ecb460ef90a9db6d32eef09542d3e850c57 (patch)
treee27ee464c97472d21e393fa234a7db9af5946423 /dns/opcode.py
parent91adcbf570bf5e00373ae47ceee0cefe684d5b70 (diff)
downloaddnspython-c8484ecb460ef90a9db6d32eef09542d3e850c57.tar.gz
in doco, text->str, binary->bytes
Diffstat (limited to 'dns/opcode.py')
-rw-r--r--dns/opcode.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/dns/opcode.py b/dns/opcode.py
index c0735ba..dd7b61b 100644
--- a/dns/opcode.py
+++ b/dns/opcode.py
@@ -52,7 +52,7 @@ class UnknownOpcode(dns.exception.DNSException):
def from_text(text):
"""Convert text into an opcode.
*text*, a ``text``, the textual opcode
Raises ``dns.opcode.UnknownOpcode`` if the opcode is unknown.
@@ -99,7 +99,7 @@ def to_text(value):
Raises ``dns.opcode.UnknownOpcode`` if the opcode is unknown.
- Returns a ``text``.
+ Returns a ``str``.
"""
text = _by_value.get(value)
@@ -52,7 +52,7 @@ class UnknownOpcode(dns.exception.DNSException):
def from_text(text):
"""Convert text into an opcode.
- *text*, a ``text``, the textual opcode
+ *text*, a ``str``, the textual opcode
Raises ``dns.opcode.UnknownOpcode`` if the opcode is unknown.